@@ -97,7 +97,7 @@ def init_log(filesave=False, filename="debug.log", level=logging.INFO):
     """
     
     if filesave:
-        logging.basicConfig(filename=filename, level=level, format='%(asctime)s %(message)s', datefmt='%d/%m/%Y %H:%M:%S', filename=filename, filemode='a')
+        logging.basicConfig(level=level, format='%(asctime)s %(message)s', datefmt='%d/%m/%Y %H:%M:%S', filename=filename, filemode='a')
 
     else:
         logging.basicConfig(level=level, format='%(asctime)s - %(levelname)s - %(message)s', datefmt='%d-%b-%y %H:%M:%S')
